Documentation
¶
Index ¶
- Variables
- func FileDescriptorSet() *descriptorpb.FileDescriptorSet
- func RegisterSinkServer(s prpc.Registrar, srv SinkServer)
- type Artifact
- func (*Artifact) Descriptor() ([]byte, []int)deprecated
- func (x *Artifact) GetBody() isArtifact_Body
- func (x *Artifact) GetContentType() string
- func (x *Artifact) GetContents() []byte
- func (x *Artifact) GetFilePath() string
- func (x *Artifact) GetGcsUri() string
- func (*Artifact) ProtoMessage()
- func (x *Artifact) ProtoReflect() protoreflect.Message
- func (x *Artifact) Reset()
- func (x *Artifact) String() string
- type Artifact_Contents
- type Artifact_FilePath
- type Artifact_GcsUri
- type DecoratedSink
- func (s *DecoratedSink) ReportInvocationLevelArtifacts(ctx context.Context, req *ReportInvocationLevelArtifactsRequest) (rsp *emptypb.Empty, err error)
- func (s *DecoratedSink) ReportTestExonerations(ctx context.Context, req *ReportTestExonerationsRequest) (rsp *ReportTestExonerationsResponse, err error)
- func (s *DecoratedSink) ReportTestResults(ctx context.Context, req *ReportTestResultsRequest) (rsp *ReportTestResultsResponse, err error)
- func (s *DecoratedSink) UpdateInvocation(ctx context.Context, req *UpdateInvocationRequest) (rsp *Invocation, err error)
- type Invocation
- type LocationTags
- type LocationTags_Dir
- func (*LocationTags_Dir) Descriptor() ([]byte, []int)deprecated
- func (x *LocationTags_Dir) GetBugComponent() *v1.BugComponent
- func (x *LocationTags_Dir) GetTags() []*v1.StringPair
- func (*LocationTags_Dir) ProtoMessage()
- func (x *LocationTags_Dir) ProtoReflect() protoreflect.Message
- func (x *LocationTags_Dir) Reset()
- func (x *LocationTags_Dir) String() string
- type LocationTags_File
- func (*LocationTags_File) Descriptor() ([]byte, []int)deprecated
- func (x *LocationTags_File) GetBugComponent() *v1.BugComponent
- func (x *LocationTags_File) GetTags() []*v1.StringPair
- func (*LocationTags_File) ProtoMessage()
- func (x *LocationTags_File) ProtoReflect() protoreflect.Message
- func (x *LocationTags_File) Reset()
- func (x *LocationTags_File) String() string
- type LocationTags_Repo
- func (*LocationTags_Repo) Descriptor() ([]byte, []int)deprecated
- func (x *LocationTags_Repo) GetDirs() map[string]*LocationTags_Dir
- func (x *LocationTags_Repo) GetFiles() map[string]*LocationTags_File
- func (*LocationTags_Repo) ProtoMessage()
- func (x *LocationTags_Repo) ProtoReflect() protoreflect.Message
- func (x *LocationTags_Repo) Reset()
- func (x *LocationTags_Repo) String() string
- type ReportInvocationLevelArtifactsRequest
- func (*ReportInvocationLevelArtifactsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ReportInvocationLevelArtifactsRequest) GetArtifacts() map[string]*Artifact
- func (*ReportInvocationLevelArtifactsRequest) ProtoMessage()
- func (x *ReportInvocationLevelArtifactsRequest) ProtoReflect() protoreflect.Message
- func (x *ReportInvocationLevelArtifactsRequest) Reset()
- func (x *ReportInvocationLevelArtifactsRequest) String() string
- type ReportTestExonerationsRequest
- func (*ReportTestExonerationsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ReportTestExonerationsRequest) GetTestExonerations() []*TestExoneration
- func (*ReportTestExonerationsRequest) ProtoMessage()
- func (x *ReportTestExonerationsRequest) ProtoReflect() protoreflect.Message
- func (x *ReportTestExonerationsRequest) Reset()
- func (x *ReportTestExonerationsRequest) String() string
- type ReportTestExonerationsResponse
- func (*ReportTestExonerationsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ReportTestExonerationsResponse) GetTestExonerationNames() []string
- func (*ReportTestExonerationsResponse) ProtoMessage()
- func (x *ReportTestExonerationsResponse) ProtoReflect() protoreflect.Message
- func (x *ReportTestExonerationsResponse) Reset()
- func (x *ReportTestExonerationsResponse) String() string
- type ReportTestResultsRequest
- func (*ReportTestResultsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ReportTestResultsRequest) GetTestResults() []*TestResult
- func (*ReportTestResultsRequest) ProtoMessage()
- func (x *ReportTestResultsRequest) ProtoReflect() protoreflect.Message
- func (x *ReportTestResultsRequest) Reset()
- func (x *ReportTestResultsRequest) String() string
- type ReportTestResultsResponse
- func (*ReportTestResultsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ReportTestResultsResponse) GetTestResultNames() []string
- func (*ReportTestResultsResponse) ProtoMessage()
- func (x *ReportTestResultsResponse) ProtoReflect() protoreflect.Message
- func (x *ReportTestResultsResponse) Reset()
- func (x *ReportTestResultsResponse) String() string
- type SinkClient
- type SinkServer
- type TestExoneration
- func (*TestExoneration) Descriptor() ([]byte, []int)deprecated
- func (x *TestExoneration) GetExplanationHtml() string
- func (x *TestExoneration) GetReason() v1.ExonerationReason
- func (x *TestExoneration) GetTestId() string
- func (x *TestExoneration) GetTestIdStructured() *TestIdentifier
- func (x *TestExoneration) GetVariant() *v1.Variant
- func (*TestExoneration) ProtoMessage()
- func (x *TestExoneration) ProtoReflect() protoreflect.Message
- func (x *TestExoneration) Reset()
- func (x *TestExoneration) String() string
- type TestIdentifier
- func (*TestIdentifier) Descriptor() ([]byte, []int)deprecated
- func (x *TestIdentifier) GetCaseNameComponents() []string
- func (x *TestIdentifier) GetCoarseName() string
- func (x *TestIdentifier) GetFineName() string
- func (*TestIdentifier) ProtoMessage()
- func (x *TestIdentifier) ProtoReflect() protoreflect.Message
- func (x *TestIdentifier) Reset()
- func (x *TestIdentifier) String() string
- type TestResult
- func (*TestResult) Descriptor() ([]byte, []int)deprecated
- func (x *TestResult) GetArtifacts() map[string]*Artifact
- func (x *TestResult) GetDuration() *durationpb.Duration
- func (x *TestResult) GetExpected() bool
- func (x *TestResult) GetFailureReason() *v1.FailureReason
- func (x *TestResult) GetFrameworkExtensions() *v1.FrameworkExtensions
- func (x *TestResult) GetProperties() *structpb.Struct
- func (x *TestResult) GetResultId() string
- func (x *TestResult) GetSkippedReason() *v1.SkippedReason
- func (x *TestResult) GetStartTime() *timestamppb.Timestamp
- func (x *TestResult) GetStatus() v1.TestStatus
- func (x *TestResult) GetStatusV2() v1.TestResult_Status
- func (x *TestResult) GetSummaryHtml() string
- func (x *TestResult) GetTags() []*v1.StringPair
- func (x *TestResult) GetTestId() string
- func (x *TestResult) GetTestIdStructured() *TestIdentifier
- func (x *TestResult) GetTestMetadata() *v1.TestMetadata
- func (x *TestResult) GetVariant() *v1.Variant
- func (*TestResult) ProtoMessage()
- func (x *TestResult) ProtoReflect() protoreflect.Message
- func (x *TestResult) Reset()
- func (x *TestResult) String() string
- type TestResultFile
- func (*TestResultFile) Descriptor() ([]byte, []int)deprecated
- func (x *TestResultFile) GetFormat() TestResultFile_Format
- func (x *TestResultFile) GetPath() string
- func (*TestResultFile) ProtoMessage()
- func (x *TestResultFile) ProtoReflect() protoreflect.Message
- func (x *TestResultFile) Reset()
- func (x *TestResultFile) String() string
- type TestResultFile_Format
- func (TestResultFile_Format) Descriptor() protoreflect.EnumDescriptor
- func (x TestResultFile_Format) Enum() *TestResultFile_Format
- func (TestResultFile_Format) EnumDescriptor() ([]byte, []int)deprecated
- func (x TestResultFile_Format) Number() protoreflect.EnumNumber
- func (x TestResultFile_Format) String() string
- func (TestResultFile_Format) Type() protoreflect.EnumType
- type UnimplementedSinkServer
- func (*UnimplementedSinkServer) ReportInvocationLevelArtifacts(context.Context, *ReportInvocationLevelArtifactsRequest) (*emptypb.Empty, error)
- func (*UnimplementedSinkServer) ReportTestExonerations(context.Context, *ReportTestExonerationsRequest) (*ReportTestExonerationsResponse, error)
- func (*UnimplementedSinkServer) ReportTestResults(context.Context, *ReportTestResultsRequest) (*ReportTestResultsResponse, error)
- func (*UnimplementedSinkServer) UpdateInvocation(context.Context, *UpdateInvocationRequest) (*Invocation, error)
- type UpdateInvocationRequest
- func (*UpdateInvocationRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateInvocationRequest) GetInvocation() *Invocation
- func (x *UpdateInvocationRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateInvocationRequest) ProtoMessage()
- func (x *UpdateInvocationRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateInvocationRequest) Reset()
- func (x *UpdateInvocationRequest) String() string
Constants ¶
This section is empty.
Variables ¶
var ( TestResultFile_Format_name = map[int32]string{ 0: "LUCI", 1: "CHROMIUM_JSON_TEST_RESULTS", 2: "GOOGLE_TEST", } TestResultFile_Format_value = map[string]int32{ "LUCI": 0, "CHROMIUM_JSON_TEST_RESULTS": 1, "GOOGLE_TEST": 2, } )
Enum value maps for TestResultFile_Format.
var File_go_chromium_org_luci_resultdb_sink_proto_v1_location_tag_proto protoreflect.FileDescriptor
var File_go_chromium_org_luci_resultdb_sink_proto_v1_sink_proto protoreflect.FileDescriptor
var File_go_chromium_org_luci_resultdb_sink_proto_v1_test_exoneration_proto protoreflect.FileDescriptor
var File_go_chromium_org_luci_resultdb_sink_proto_v1_test_result_proto protoreflect.FileDescriptor
Functions ¶
func FileDescriptorSet ¶
func FileDescriptorSet() *descriptorpb.FileDescriptorSet
FileDescriptorSet returns a descriptor set for this proto package, which includes all defined services, and all transitive dependencies.
Will not return nil.
Do NOT modify the returned descriptor.
func RegisterSinkServer ¶
func RegisterSinkServer(s prpc.Registrar, srv SinkServer)
Types ¶
type Artifact ¶
type Artifact struct {
// Body should be only one of the following:
// - file_path (file should exist. contents & gcs_uri should not be set)
// - contents (file_path & gcs_uri should not be set)
// - gcs_uri for GCS artifact (file_path & contents should not be set)
//
// Types that are valid to be assigned to Body:
//
// *Artifact_FilePath
// *Artifact_Contents
// *Artifact_GcsUri
Body isArtifact_Body `protobuf_oneof:"body"`
// Equivalent of luci.resultdb.v1.Artifact.content_type.
ContentType string `protobuf:"bytes,3,opt,name=content_type,json=contentType,proto3" json:"content_type,omitempty"`
// contains filtered or unexported fields
}
A local equivalent of luci.resultdb.Artifact message in ../../../proto/v1/artifact.proto. See its comments for details. Does not have a name or artifact_id because they are represented by the TestResult.artifacts map key. Next id: 5
func (*Artifact) Descriptor
deprecated
func (*Artifact) GetContentType ¶
func (*Artifact) GetContents ¶
func (*Artifact) GetFilePath ¶
func (*Artifact) ProtoMessage ¶
func (*Artifact) ProtoMessage()
func (*Artifact) ProtoReflect ¶
func (x *Artifact) ProtoReflect() protoreflect.Message
type Artifact_Contents ¶
type Artifact_Contents struct {
// Contents of the artifact. Useful when sending a file from a different
// machine.
// TODO(nodir, sajjadm): allow sending contents in chunks.
Contents []byte `protobuf:"bytes,2,opt,name=contents,proto3,oneof"`
}
type Artifact_FilePath ¶
type Artifact_FilePath struct {
// Absolute path to the artifact file on the same machine as the
// ResultSink server.
FilePath string `protobuf:"bytes,1,opt,name=file_path,json=filePath,proto3,oneof"`
}
type Artifact_GcsUri ¶
type Artifact_GcsUri struct {
// The GCS URI of the artifact if it's stored in GCS.
GcsUri string `protobuf:"bytes,4,opt,name=gcs_uri,json=gcsUri,proto3,oneof"`
}
type DecoratedSink ¶
type DecoratedSink struct {
// Service is the service to decorate.
Service SinkServer
// Prelude is called for each method before forwarding the call to Service.
// If Prelude returns an error, then the call is skipped and the error is
// processed via the Postlude (if one is defined), or it is returned directly.
Prelude func(ctx context.Context, methodName string, req proto.Message) (context.Context, error)
// Postlude is called for each method after Service has processed the call, or
// after the Prelude has returned an error. This takes the Service's
// response proto (which may be nil) and/or any error. The decorated
// service will return the response (possibly mutated) and error that Postlude
// returns.
Postlude func(ctx context.Context, methodName string, rsp proto.Message, err error) error
}
func (*DecoratedSink) ReportInvocationLevelArtifacts ¶
func (s *DecoratedSink) ReportInvocationLevelArtifacts(ctx context.Context, req *ReportInvocationLevelArtifactsRequest) (rsp *emptypb.Empty, err error)
func (*DecoratedSink) ReportTestExonerations ¶
func (s *DecoratedSink) ReportTestExonerations(ctx context.Context, req *ReportTestExonerationsRequest) (rsp *ReportTestExonerationsResponse, err error)
func (*DecoratedSink) ReportTestResults ¶
func (s *DecoratedSink) ReportTestResults(ctx context.Context, req *ReportTestResultsRequest) (rsp *ReportTestResultsResponse, err error)
func (*DecoratedSink) UpdateInvocation ¶
func (s *DecoratedSink) UpdateInvocation(ctx context.Context, req *UpdateInvocationRequest) (rsp *Invocation, err error)
type Invocation ¶
type Invocation struct {
// See 'extended_properties' field of the luci.resultdb.v1.Invocation message
// for details.
ExtendedProperties map[string]*structpb.Struct `` /* 189-byte string literal not displayed */
// contains filtered or unexported fields
}
A local equivalent of the luci.resultdb.v1.Invocation message. The 'name' field is omitted as result sink keeps track of which invocation is being uploaded to.
func (*Invocation) Descriptor
deprecated
func (*Invocation) Descriptor() ([]byte, []int)
Deprecated: Use Invocation.ProtoReflect.Descriptor instead.
func (*Invocation) GetExtendedProperties ¶
func (x *Invocation) GetExtendedProperties() map[string]*structpb.Struct
func (*Invocation) ProtoMessage ¶
func (*Invocation) ProtoMessage()
func (*Invocation) ProtoReflect ¶
func (x *Invocation) ProtoReflect() protoreflect.Message
func (*Invocation) Reset ¶
func (x *Invocation) Reset()
func (*Invocation) String ¶
func (x *Invocation) String() string
type LocationTags ¶
type LocationTags struct {
// The key is a Gitiles URL as the identifier for a repo.
// Format for Gitiles URL: https://<host>/<project>
// For example "https://chromium.googlesource.com/chromium/src"
// Must not end with ".git".
Repos map[string]*LocationTags_Repo `` /* 137-byte string literal not displayed */
// contains filtered or unexported fields
}
Maps from directory paths to extra fields to attach to TestResults. When converted to JSON format, it will look like below:
{
"repos": {
"https://chromium.googlesource.com/chromium/src" : {
"dirs": {
".": {
"tags": {
"teamEmail": "team_email@chromium.org"
}
},
"foo": {
"tags": {
"teamEmail": "team_email@chromium.org",
"os": "WINDOWS"
},
"bug_component": {
"issue_tracker": {
"component_id": "17171717"
}
}
}
}
"files": {
"./file.txt": {
"tags": {
"teamEmail": "other_email@chromium.org",
"os": "WINDOWS"
},
"bug_component": {
"issue_tracker": {
"component_id": "123456"
}
}
}
}
}
}
}
N.B. This message is called 'LocationTags' because it was previously only used for tags, but this is no longer true.
func (*LocationTags) Descriptor
deprecated
func (*LocationTags) Descriptor() ([]byte, []int)
Deprecated: Use LocationTags.ProtoReflect.Descriptor instead.
func (*LocationTags) GetRepos ¶
func (x *LocationTags) GetRepos() map[string]*LocationTags_Repo
func (*LocationTags) ProtoMessage ¶
func (*LocationTags) ProtoMessage()
func (*LocationTags) ProtoReflect ¶
func (x *LocationTags) ProtoReflect() protoreflect.Message
func (*LocationTags) Reset ¶
func (x *LocationTags) Reset()
func (*LocationTags) String ¶
func (x *LocationTags) String() string
type LocationTags_Dir ¶
type LocationTags_Dir struct {
// If a key is not defined for subdir, but defined for an ancestor dir, then
// the value(s) in the ancestor is implied.
//
// A key can be repeated.
Tags []*v1.StringPair `protobuf:"bytes,1,rep,name=tags,proto3" json:"tags,omitempty"`
// The issue tracker component associated with the test, if any.
// Bugs related to the test may be filed here.
// Populated to test_metadata.bug_component.
BugComponent *v1.BugComponent `protobuf:"bytes,2,opt,name=bug_component,json=bugComponent,proto3" json:"bug_component,omitempty"`
// contains filtered or unexported fields
}
Extra tags to attach to TestResults for a directory.
func (*LocationTags_Dir) Descriptor
deprecated
func (*LocationTags_Dir) Descriptor() ([]byte, []int)
Deprecated: Use LocationTags_Dir.ProtoReflect.Descriptor instead.
func (*LocationTags_Dir) GetBugComponent ¶
func (x *LocationTags_Dir) GetBugComponent() *v1.BugComponent
func (*LocationTags_Dir) GetTags ¶
func (x *LocationTags_Dir) GetTags() []*v1.StringPair
func (*LocationTags_Dir) ProtoMessage ¶
func (*LocationTags_Dir) ProtoMessage()
func (*LocationTags_Dir) ProtoReflect ¶
func (x *LocationTags_Dir) ProtoReflect() protoreflect.Message
func (*LocationTags_Dir) Reset ¶
func (x *LocationTags_Dir) Reset()
func (*LocationTags_Dir) String ¶
func (x *LocationTags_Dir) String() string
type LocationTags_File ¶
type LocationTags_File struct {
// A key can be repeated.
Tags []*v1.StringPair `protobuf:"bytes,1,rep,name=tags,proto3" json:"tags,omitempty"`
// The issue tracker component associated with the test, if any.
// Bugs related to the test may be filed here.
// Populated to test_metadata.bug_component.
BugComponent *v1.BugComponent `protobuf:"bytes,2,opt,name=bug_component,json=bugComponent,proto3" json:"bug_component,omitempty"`
// contains filtered or unexported fields
}
Extra tags to attach to TestResults for a file.
func (*LocationTags_File) Descriptor
deprecated
func (*LocationTags_File) Descriptor() ([]byte, []int)
Deprecated: Use LocationTags_File.ProtoReflect.Descriptor instead.
func (*LocationTags_File) GetBugComponent ¶
func (x *LocationTags_File) GetBugComponent() *v1.BugComponent
func (*LocationTags_File) GetTags ¶
func (x *LocationTags_File) GetTags() []*v1.StringPair
func (*LocationTags_File) ProtoMessage ¶
func (*LocationTags_File) ProtoMessage()
func (*LocationTags_File) ProtoReflect ¶
func (x *LocationTags_File) ProtoReflect() protoreflect.Message
func (*LocationTags_File) Reset ¶
func (x *LocationTags_File) Reset()
func (*LocationTags_File) String ¶
func (x *LocationTags_File) String() string
type LocationTags_Repo ¶
type LocationTags_Repo struct {
// The key is a relative dir path.
// "" means repo root and represents default for all subdirs.
// Must use forward slash as a dir separator.
Dirs map[string]*LocationTags_Dir `` /* 135-byte string literal not displayed */
// The key is a relative path to a file.
// Same rules apply as dir.
Files map[string]*LocationTags_File `` /* 137-byte string literal not displayed */
// contains filtered or unexported fields
}
Map from directory paths in a repo to extra tags to attach to TestResults.
func (*LocationTags_Repo) Descriptor
deprecated
func (*LocationTags_Repo) Descriptor() ([]byte, []int)
Deprecated: Use LocationTags_Repo.ProtoReflect.Descriptor instead.
func (*LocationTags_Repo) GetDirs ¶
func (x *LocationTags_Repo) GetDirs() map[string]*LocationTags_Dir
func (*LocationTags_Repo) GetFiles ¶
func (x *LocationTags_Repo) GetFiles() map[string]*LocationTags_File
func (*LocationTags_Repo) ProtoMessage ¶
func (*LocationTags_Repo) ProtoMessage()
func (*LocationTags_Repo) ProtoReflect ¶
func (x *LocationTags_Repo) ProtoReflect() protoreflect.Message
func (*LocationTags_Repo) Reset ¶
func (x *LocationTags_Repo) Reset()
func (*LocationTags_Repo) String ¶
func (x *LocationTags_Repo) String() string
type ReportInvocationLevelArtifactsRequest ¶
type ReportInvocationLevelArtifactsRequest struct {
// Invocation-level artifacts to report.
// The map key is an artifact id.
Artifacts map[string]*Artifact `` /* 145-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*ReportInvocationLevelArtifactsRequest) Descriptor
deprecated
func (*ReportInvocationLevelArtifactsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReportInvocationLevelArtifactsRequest.ProtoReflect.Descriptor instead.
func (*ReportInvocationLevelArtifactsRequest) GetArtifacts ¶
func (x *ReportInvocationLevelArtifactsRequest) GetArtifacts() map[string]*Artifact
func (*ReportInvocationLevelArtifactsRequest) ProtoMessage ¶
func (*ReportInvocationLevelArtifactsRequest) ProtoMessage()
func (*ReportInvocationLevelArtifactsRequest) ProtoReflect ¶
func (x *ReportInvocationLevelArtifactsRequest) ProtoReflect() protoreflect.Message
func (*ReportInvocationLevelArtifactsRequest) Reset ¶
func (x *ReportInvocationLevelArtifactsRequest) Reset()
func (*ReportInvocationLevelArtifactsRequest) String ¶
func (x *ReportInvocationLevelArtifactsRequest) String() string
type ReportTestExonerationsRequest ¶
type ReportTestExonerationsRequest struct {
// Test exponerations to report.
TestExonerations []*TestExoneration `protobuf:"bytes,1,rep,name=test_exonerations,json=testExonerations,proto3" json:"test_exonerations,omitempty"`
// contains filtered or unexported fields
}
func (*ReportTestExonerationsRequest) Descriptor
deprecated
func (*ReportTestExonerationsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReportTestExonerationsRequest.ProtoReflect.Descriptor instead.
func (*ReportTestExonerationsRequest) GetTestExonerations ¶
func (x *ReportTestExonerationsRequest) GetTestExonerations() []*TestExoneration
func (*ReportTestExonerationsRequest) ProtoMessage ¶
func (*ReportTestExonerationsRequest) ProtoMessage()
func (*ReportTestExonerationsRequest) ProtoReflect ¶
func (x *ReportTestExonerationsRequest) ProtoReflect() protoreflect.Message
func (*ReportTestExonerationsRequest) Reset ¶
func (x *ReportTestExonerationsRequest) Reset()
func (*ReportTestExonerationsRequest) String ¶
func (x *ReportTestExonerationsRequest) String() string
type ReportTestExonerationsResponse ¶
type ReportTestExonerationsResponse struct {
// List of unique identifiers that can be used to link to these exonerations
// or requested via luci.resultdb.v1.ResultDB service.
TestExonerationNames []string `protobuf:"bytes,1,rep,name=test_exoneration_names,json=testExonerationNames,proto3" json:"test_exoneration_names,omitempty"`
// contains filtered or unexported fields
}
func (*ReportTestExonerationsResponse) Descriptor
deprecated
func (*ReportTestExonerationsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ReportTestExonerationsResponse.ProtoReflect.Descriptor instead.
func (*ReportTestExonerationsResponse) GetTestExonerationNames ¶
func (x *ReportTestExonerationsResponse) GetTestExonerationNames() []string
func (*ReportTestExonerationsResponse) ProtoMessage ¶
func (*ReportTestExonerationsResponse) ProtoMessage()
func (*ReportTestExonerationsResponse) ProtoReflect ¶
func (x *ReportTestExonerationsResponse) ProtoReflect() protoreflect.Message
func (*ReportTestExonerationsResponse) Reset ¶
func (x *ReportTestExonerationsResponse) Reset()
func (*ReportTestExonerationsResponse) String ¶
func (x *ReportTestExonerationsResponse) String() string
type ReportTestResultsRequest ¶
type ReportTestResultsRequest struct {
// Test results to report.
TestResults []*TestResult `protobuf:"bytes,1,rep,name=test_results,json=testResults,proto3" json:"test_results,omitempty"`
// contains filtered or unexported fields
}
func (*ReportTestResultsRequest) Descriptor
deprecated
func (*ReportTestResultsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReportTestResultsRequest.ProtoReflect.Descriptor instead.
func (*ReportTestResultsRequest) GetTestResults ¶
func (x *ReportTestResultsRequest) GetTestResults() []*TestResult
func (*ReportTestResultsRequest) ProtoMessage ¶
func (*ReportTestResultsRequest) ProtoMessage()
func (*ReportTestResultsRequest) ProtoReflect ¶
func (x *ReportTestResultsRequest) ProtoReflect() protoreflect.Message
func (*ReportTestResultsRequest) Reset ¶
func (x *ReportTestResultsRequest) Reset()
func (*ReportTestResultsRequest) String ¶
func (x *ReportTestResultsRequest) String() string
type ReportTestResultsResponse ¶
type ReportTestResultsResponse struct {
// List of unique identifiers that can be used to link to these results
// or requested via luci.resultdb.v1.ResultDB service.
TestResultNames []string `protobuf:"bytes,1,rep,name=test_result_names,json=testResultNames,proto3" json:"test_result_names,omitempty"`
// contains filtered or unexported fields
}
func (*ReportTestResultsResponse) Descriptor
deprecated
func (*ReportTestResultsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ReportTestResultsResponse.ProtoReflect.Descriptor instead.
func (*ReportTestResultsResponse) GetTestResultNames ¶
func (x *ReportTestResultsResponse) GetTestResultNames() []string
func (*ReportTestResultsResponse) ProtoMessage ¶
func (*ReportTestResultsResponse) ProtoMessage()
func (*ReportTestResultsResponse) ProtoReflect ¶
func (x *ReportTestResultsResponse) ProtoReflect() protoreflect.Message
func (*ReportTestResultsResponse) Reset ¶
func (x *ReportTestResultsResponse) Reset()
func (*ReportTestResultsResponse) String ¶
func (x *ReportTestResultsResponse) String() string
type SinkClient ¶
type SinkClient interface {
// Reports test results.
ReportTestResults(ctx context.Context, in *ReportTestResultsRequest, opts ...grpc.CallOption) (*ReportTestResultsResponse, error)
// Reports invocation-level artifacts.
// To upload result-level artifact, use ReportTestResults instead.
ReportInvocationLevelArtifacts(ctx context.Context, in *ReportInvocationLevelArtifactsRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Update an invocation
UpdateInvocation(ctx context.Context, in *UpdateInvocationRequest, opts ...grpc.CallOption) (*Invocation, error)
ReportTestExonerations(ctx context.Context, in *ReportTestExonerationsRequest, opts ...grpc.CallOption) (*ReportTestExonerationsResponse, error)
}
SinkClient is the client API for Sink service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewSinkClient ¶
func NewSinkClient(cc grpc.ClientConnInterface) SinkClient
func NewSinkPRPCClient ¶
func NewSinkPRPCClient(client *prpc.Client) SinkClient
type SinkServer ¶
type SinkServer interface {
// Reports test results.
ReportTestResults(context.Context, *ReportTestResultsRequest) (*ReportTestResultsResponse, error)
// Reports invocation-level artifacts.
// To upload result-level artifact, use ReportTestResults instead.
ReportInvocationLevelArtifacts(context.Context, *ReportInvocationLevelArtifactsRequest) (*emptypb.Empty, error)
// Update an invocation
UpdateInvocation(context.Context, *UpdateInvocationRequest) (*Invocation, error)
ReportTestExonerations(context.Context, *ReportTestExonerationsRequest) (*ReportTestExonerationsResponse, error)
}
SinkServer is the server API for Sink service.
type TestExoneration ¶
type TestExoneration struct {
// The structured identifier of the test that is being exonerated.
TestIdStructured *TestIdentifier `protobuf:"bytes,1,opt,name=test_id_structured,json=testIdStructured,proto3" json:"test_id_structured,omitempty"`
// The flat test id of the test that is being exonerated.
// DEPRECATED: set test_id_structured instead.
TestId string `protobuf:"bytes,2,opt,name=test_id,json=testId,proto3" json:"test_id,omitempty"`
// The variant of the test that is being exonerated.
// DEPRECATED: set test_id_structured instead.
Variant *v1.Variant `protobuf:"bytes,3,opt,name=variant,proto3" json:"variant,omitempty"`
// Human readable reasoning behind the exoneration, in HTML.
// MUST be sanitized before rendering in the browser.
ExplanationHtml string `protobuf:"bytes,4,opt,name=explanation_html,json=explanationHtml,proto3" json:"explanation_html,omitempty"`
// Reasoning behind the exoneration, in machine-readable form.
// Used to assist downstream analyses, such as automatic bug-filing.
// This allow detection of e.g. critical tests failing in presubmit,
// even if they are being exonerated because they fail on other CLs.
Reason v1.ExonerationReason `protobuf:"varint,5,opt,name=reason,proto3,enum=luci.resultdb.v1.ExonerationReason" json:"reason,omitempty"`
// contains filtered or unexported fields
}
A local equivalent of luci.resultdb.TestExoneration message in ../../v1/test_exoneration.proto.
func (*TestExoneration) Descriptor
deprecated
func (*TestExoneration) Descriptor() ([]byte, []int)
Deprecated: Use TestExoneration.ProtoReflect.Descriptor instead.
func (*TestExoneration) GetExplanationHtml ¶
func (x *TestExoneration) GetExplanationHtml() string
func (*TestExoneration) GetReason ¶
func (x *TestExoneration) GetReason() v1.ExonerationReason
func (*TestExoneration) GetTestId ¶
func (x *TestExoneration) GetTestId() string
func (*TestExoneration) GetTestIdStructured ¶
func (x *TestExoneration) GetTestIdStructured() *TestIdentifier
func (*TestExoneration) GetVariant ¶
func (x *TestExoneration) GetVariant() *v1.Variant
func (*TestExoneration) ProtoMessage ¶
func (*TestExoneration) ProtoMessage()
func (*TestExoneration) ProtoReflect ¶
func (x *TestExoneration) ProtoReflect() protoreflect.Message
func (*TestExoneration) Reset ¶
func (x *TestExoneration) Reset()
func (*TestExoneration) String ¶
func (x *TestExoneration) String() string
type TestIdentifier ¶
type TestIdentifier struct {
// Equivalent of luci.resultdb.v1.TestIdentifier.coarse_name.
CoarseName string `protobuf:"bytes,1,opt,name=coarse_name,json=coarseName,proto3" json:"coarse_name,omitempty"`
// Equivalent of luci.resultdb.v1.TestIdentifier.fine_name.
FineName string `protobuf:"bytes,2,opt,name=fine_name,json=fineName,proto3" json:"fine_name,omitempty"`
// Equivalent of luci.resultdb.v1.TestIdentifier.case_name, but
// specified as a set of components to avoid uploaders needing to handle
// encoding themselves.
//
// Typically, only one component is specified: the JUnit/GTest/... method name.
// E.g. ["barTest"]
//
// However, in case of extended hierarchies (e.g. Mocha/Jest test hierarchies,
// some parameterised tests), multiple components MAY be specified.
// E.g. ["GerritChangesContentCell", "when_there_are_changes", "should_expand/collapse_correctly"]
//
// When reporting the status of fine name-level setup/teardown, use
// the special value ["*fixture"].
//
// See luci.resultdb.v1.TestIdentifier.case_name for detailed application
// guidance.
CaseNameComponents []string `protobuf:"bytes,3,rep,name=case_name_components,json=caseNameComponents,proto3" json:"case_name_components,omitempty"`
// contains filtered or unexported fields
}
A local equivalent of luci.resultdb.v1.TestIdentifier message in ../../../proto/v1/common.proto. See its comments for details.
func (*TestIdentifier) Descriptor
deprecated
func (*TestIdentifier) Descriptor() ([]byte, []int)
Deprecated: Use TestIdentifier.ProtoReflect.Descriptor instead.
func (*TestIdentifier) GetCaseNameComponents ¶
func (x *TestIdentifier) GetCaseNameComponents() []string
func (*TestIdentifier) GetCoarseName ¶
func (x *TestIdentifier) GetCoarseName() string
func (*TestIdentifier) GetFineName ¶
func (x *TestIdentifier) GetFineName() string
func (*TestIdentifier) ProtoMessage ¶
func (*TestIdentifier) ProtoMessage()
func (*TestIdentifier) ProtoReflect ¶
func (x *TestIdentifier) ProtoReflect() protoreflect.Message
func (*TestIdentifier) Reset ¶
func (x *TestIdentifier) Reset()
func (*TestIdentifier) String ¶
func (x *TestIdentifier) String() string
type TestResult ¶
type TestResult struct {
// Equivalent of luci.resultdb.v1.TestResult.test_id_structured.
//
// To support migration from test_id to test_id_structured,
// it is acceptable to set both test_id_structured and test_id.
// If rdb stream is run with a module name specified, test_id_structured
// will be used. Otherwise, test_id will be used.
TestIdStructured *TestIdentifier `protobuf:"bytes,15,opt,name=test_id_structured,json=testIdStructured,proto3" json:"test_id_structured,omitempty"`
// DEPRECATED: set test_id_structured instead.
// Equivalent of luci.resultdb.v1.TestResult.test_id.
//
// To facilitate migrating from legacy test IDs to structured IDs,
// existing test harnesses setting this field should keep setting
// this field.
// When structured IDs are used, if this ID is set and -previous-test-id-prefix
// is passed to ResultSink the combination will populate into
// test_metadata.previous_test_id.
TestId string `protobuf:"bytes,1,opt,name=test_id,json=testId,proto3" json:"test_id,omitempty"`
// Equivalent of luci.resultdb.v1.TestResult.result_id.
//
// If omitted, a random, unique ID is generated..
ResultId string `protobuf:"bytes,2,opt,name=result_id,json=resultId,proto3" json:"result_id,omitempty"`
// DEPRECATED: use status_v2 instead.
// Equivalent of luci.resultdb.v1.TestResult.expected.
Expected bool `protobuf:"varint,3,opt,name=expected,proto3" json:"expected,omitempty"`
// DEPRECATED: use status_v2 instead.
// Equivalent of luci.resultdb.v1.TestResult.status.
Status v1.TestStatus `protobuf:"varint,4,opt,name=status,proto3,enum=luci.resultdb.v1.TestStatus" json:"status,omitempty"`
// Equivalent of luci.resultdb.v1.TestResult.status_v2.
StatusV2 v1.TestResult_Status `` /* 127-byte string literal not displayed */
// Equivalent of luci.resultdb.v1.TestResult.summary_html.
SummaryHtml string `protobuf:"bytes,5,opt,name=summary_html,json=summaryHtml,proto3" json:"summary_html,omitempty"`
// Equivalent of luci.resultdb.v1.TestResult.start_time.
StartTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
// Equivalent of luci.resultdb.v1.TestResult.duration.
Duration *durationpb.Duration `protobuf:"bytes,7,opt,name=duration,proto3" json:"duration,omitempty"`
// Equivalent of luci.resultdb.v1.TestResult.tags.
Tags []*v1.StringPair `protobuf:"bytes,8,rep,name=tags,proto3" json:"tags,omitempty"`
// Artifacts to upload and associate with this test result.
// The map key is an artifact id.
Artifacts map[string]*Artifact `` /* 145-byte string literal not displayed */
// Equivalent of luci.resultdb.v1.TestResult.test_metadata.
// Do not set previous_test_id. It will be ignored by ResultSink.
TestMetadata *v1.TestMetadata `protobuf:"bytes,11,opt,name=test_metadata,json=testMetadata,proto3" json:"test_metadata,omitempty"`
// Equivalent of luci.resultdb.v1.TestResult.failure_reason.
FailureReason *v1.FailureReason `protobuf:"bytes,12,opt,name=failure_reason,json=failureReason,proto3" json:"failure_reason,omitempty"`
// DEPRECATED: pass the module-level variant to rdb stream. If there is further
// variant information at the test case level, encode it into the test ID.
// Equivalent of luci.resultdb.v1.TestResult.variant.
// The variant for all test cases should be passed by command line args to rdb
// stream, however you can override or add to the variant on a per test case
// basis using this field.
Variant *v1.Variant `protobuf:"bytes,13,opt,name=variant,proto3" json:"variant,omitempty"`
// Arbitrary JSON object that contains structured, domain-specific properties
// of the test result.
//
// The serialized size must be <= 8 KB.
Properties *structpb.Struct `protobuf:"bytes,14,opt,name=properties,proto3" json:"properties,omitempty"`
// The reason why a test was skipped.
// Equivalent of luci.resultdb.v1.TestResult.skipped_reason.
SkippedReason *v1.SkippedReason `protobuf:"bytes,21,opt,name=skipped_reason,json=skippedReason,proto3" json:"skipped_reason,omitempty"`
// Test results framework-specific data model elements.
// Equivalent of luci.resultdb.v1.TestResult.framework_extensions.
FrameworkExtensions *v1.FrameworkExtensions `protobuf:"bytes,22,opt,name=framework_extensions,json=frameworkExtensions,proto3" json:"framework_extensions,omitempty"`
// contains filtered or unexported fields
}
A local equivalent of luci.resultdb.v1.TestResult message in ../../../proto/v1/test_result.proto. See its comments for details. Next ID: 17.
func (*TestResult) Descriptor
deprecated
func (*TestResult) Descriptor() ([]byte, []int)
Deprecated: Use TestResult.ProtoReflect.Descriptor instead.
func (*TestResult) GetArtifacts ¶
func (x *TestResult) GetArtifacts() map[string]*Artifact
func (*TestResult) GetDuration ¶
func (x *TestResult) GetDuration() *durationpb.Duration
func (*TestResult) GetExpected ¶
func (x *TestResult) GetExpected() bool
func (*TestResult) GetFailureReason ¶
func (x *TestResult) GetFailureReason() *v1.FailureReason
func (*TestResult) GetFrameworkExtensions ¶
func (x *TestResult) GetFrameworkExtensions() *v1.FrameworkExtensions
func (*TestResult) GetProperties ¶
func (x *TestResult) GetProperties() *structpb.Struct
func (*TestResult) GetResultId ¶
func (x *TestResult) GetResultId() string
func (*TestResult) GetSkippedReason ¶
func (x *TestResult) GetSkippedReason() *v1.SkippedReason
func (*TestResult) GetStartTime ¶
func (x *TestResult) GetStartTime() *timestamppb.Timestamp
func (*TestResult) GetStatus ¶
func (x *TestResult) GetStatus() v1.TestStatus
func (*TestResult) GetStatusV2 ¶
func (x *TestResult) GetStatusV2() v1.TestResult_Status
func (*TestResult) GetSummaryHtml ¶
func (x *TestResult) GetSummaryHtml() string
func (*TestResult) GetTags ¶
func (x *TestResult) GetTags() []*v1.StringPair
func (*TestResult) GetTestId ¶
func (x *TestResult) GetTestId() string
func (*TestResult) GetTestIdStructured ¶
func (x *TestResult) GetTestIdStructured() *TestIdentifier
func (*TestResult) GetTestMetadata ¶
func (x *TestResult) GetTestMetadata() *v1.TestMetadata
func (*TestResult) GetVariant ¶
func (x *TestResult) GetVariant() *v1.Variant
func (*TestResult) ProtoMessage ¶
func (*TestResult) ProtoMessage()
func (*TestResult) ProtoReflect ¶
func (x *TestResult) ProtoReflect() protoreflect.Message
func (*TestResult) Reset ¶
func (x *TestResult) Reset()
func (*TestResult) String ¶
func (x *TestResult) String() string
type TestResultFile ¶
type TestResultFile struct {
// Absolute OS-native path to the results file on the same machine as the
// ResultSink server.
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// Format of the file.
Format TestResultFile_Format `protobuf:"varint,2,opt,name=format,proto3,enum=luci.resultsink.v1.TestResultFile_Format" json:"format,omitempty"`
// contains filtered or unexported fields
}
A file with test results.
func (*TestResultFile) Descriptor
deprecated
func (*TestResultFile) Descriptor() ([]byte, []int)
Deprecated: Use TestResultFile.ProtoReflect.Descriptor instead.
func (*TestResultFile) GetFormat ¶
func (x *TestResultFile) GetFormat() TestResultFile_Format
func (*TestResultFile) GetPath ¶
func (x *TestResultFile) GetPath() string
func (*TestResultFile) ProtoMessage ¶
func (*TestResultFile) ProtoMessage()
func (*TestResultFile) ProtoReflect ¶
func (x *TestResultFile) ProtoReflect() protoreflect.Message
func (*TestResultFile) Reset ¶
func (x *TestResultFile) Reset()
func (*TestResultFile) String ¶
func (x *TestResultFile) String() string
type TestResultFile_Format ¶
type TestResultFile_Format int32
A result file format.
const ( // The file is a sequence of TestResult JSON objects (not a JSON Array). // The default format. TestResultFile_LUCI TestResultFile_Format = 0 // Chromium's JSON Test Results format // https://chromium.googlesource.com/chromium/src/+/master/docs/testing/json_test_results_format.md TestResultFile_CHROMIUM_JSON_TEST_RESULTS TestResultFile_Format = 1 // GTest format. // Not well documented. // Implementation: // https://cs.chromium.org/chromium/src/base/test/launcher/test_results_tracker.cc TestResultFile_GOOGLE_TEST TestResultFile_Format = 2 )
func (TestResultFile_Format) Descriptor ¶
func (TestResultFile_Format) Descriptor() protoreflect.EnumDescriptor
func (TestResultFile_Format) Enum ¶
func (x TestResultFile_Format) Enum() *TestResultFile_Format
func (TestResultFile_Format) EnumDescriptor
deprecated
func (TestResultFile_Format) EnumDescriptor() ([]byte, []int)
Deprecated: Use TestResultFile_Format.Descriptor instead.
func (TestResultFile_Format) Number ¶
func (x TestResultFile_Format) Number() protoreflect.EnumNumber
func (TestResultFile_Format) String ¶
func (x TestResultFile_Format) String() string
func (TestResultFile_Format) Type ¶
func (TestResultFile_Format) Type() protoreflect.EnumType
type UnimplementedSinkServer ¶
type UnimplementedSinkServer struct {
}
UnimplementedSinkServer can be embedded to have forward compatible implementations.
func (*UnimplementedSinkServer) ReportInvocationLevelArtifacts ¶
func (*UnimplementedSinkServer) ReportInvocationLevelArtifacts(context.Context, *ReportInvocationLevelArtifactsRequest) (*emptypb.Empty, error)
func (*UnimplementedSinkServer) ReportTestExonerations ¶
func (*UnimplementedSinkServer) ReportTestExonerations(context.Context, *ReportTestExonerationsRequest) (*ReportTestExonerationsResponse, error)
func (*UnimplementedSinkServer) ReportTestResults ¶
func (*UnimplementedSinkServer) ReportTestResults(context.Context, *ReportTestResultsRequest) (*ReportTestResultsResponse, error)
func (*UnimplementedSinkServer) UpdateInvocation ¶
func (*UnimplementedSinkServer) UpdateInvocation(context.Context, *UpdateInvocationRequest) (*Invocation, error)
type UpdateInvocationRequest ¶
type UpdateInvocationRequest struct {
// Invocation to update.
Invocation *Invocation `protobuf:"bytes,1,opt,name=invocation,proto3" json:"invocation,omitempty"`
// The list of fields to be updated. See https://google.aip.dev/161.
//
// The following paths can be used for extended_properties:
// * "extended_properties" to target the whole extended_properties,
// * "extended_properties.some_key" to target one key of extended_properties.
// See sink/sink_server.go for implementation.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateInvocationRequest) Descriptor
deprecated
func (*UpdateInvocationRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateInvocationRequest.ProtoReflect.Descriptor instead.
func (*UpdateInvocationRequest) GetInvocation ¶
func (x *UpdateInvocationRequest) GetInvocation() *Invocation
func (*UpdateInvocationRequest) GetUpdateMask ¶
func (x *UpdateInvocationRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateInvocationRequest) ProtoMessage ¶
func (*UpdateInvocationRequest) ProtoMessage()
func (*UpdateInvocationRequest) ProtoReflect ¶
func (x *UpdateInvocationRequest) ProtoReflect() protoreflect.Message
func (*UpdateInvocationRequest) Reset ¶
func (x *UpdateInvocationRequest) Reset()
func (*UpdateInvocationRequest) String ¶
func (x *UpdateInvocationRequest) String() string